/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http//www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is ART Ontology API.
 *
 * The Initial Developer of the Original Code is University of Roma Tor Vergata.
 * Portions created by University of Roma Tor Vergata are Copyright (C) 2007.
 * All Rights Reserved.
 *
 * ART Ontology API was developed by the Artificial Intelligence Research Group
 * (art.uniroma2.it) at the University of Roma Tor Vergata
 * Current information about the ART Ontology API can be obtained at 
 * http//art.uniroma2.it/owlart
 *
 */

package it.uniroma2.art.owlart.filter;

import com.google.common.base.Predicate;

import it.uniroma2.art.owlart.exceptions.ModelAccessException;
import it.uniroma2.art.owlart.model.ARTNode;
import it.uniroma2.art.owlart.model.ARTResource;
import it.uniroma2.art.owlart.model.ARTURIResource;
import it.uniroma2.art.owlart.models.SKOSModel;

/**
 * this filter passes all RDF nodes which are actually URI (that is, return <code>true</code> on
 * {@link ARTNode#isURIResource()} )
 * 
 * @author Armando Stellato
 * 
 */
public class ConceptsInSchemePredicate implements Predicate<ARTURIResource> {
	
	SKOSModel model;	
	ARTURIResource scheme;
	ARTResource[] graphs;
	
	public static ConceptsInSchemePredicate getFilter(SKOSModel model, ARTURIResource scheme, ARTResource... graphs) {
		return new ConceptsInSchemePredicate(model, scheme, graphs);
	}
	
	protected ConceptsInSchemePredicate(SKOSModel model, ARTURIResource scheme, ARTResource[] graphs) {
		this.model = model;
		this.scheme = scheme;
		this.graphs = graphs;
	}
		
	public boolean apply(ARTURIResource skosConcept) {
		try {
			return model.isInScheme(skosConcept, scheme, graphs);
		} catch (ModelAccessException e) {
			return false;
		}
	}

}
